@@ -25,7 +25,7 @@
 #' @param border Set the \code{border} 'normal', 'alert', or 'flash'.
 #' @param autoComplete Enable/Disable code completion. See \code{\link{aceEditor}}
 #'   for details.
-#' @param autoCompleters List of completers to enable. If set to \code{NULL},
+#' @param autoCompleters Character vector of completers to enable. If set to \code{NULL},
 #'   all completers will be disabled.
 #' @param autoCompleteList If set to \code{NULL}, existing static completions
 #'   list will be unset. See \code{\link{aceEditor}} for details.
@@ -53,6 +53,12 @@ updateAceEditor <- function(
   if (missing(session) || missing(editorId)) {
     stop("Must provide both a session and an editorId to update Ace editor settings")
   }
+  if(!all(autoComplete %in% c("disabled", "enabled", "live")))
+    stop("updateAceEditor: Incorrectly formatted autoComplete parameter")
+  if(!all(border %in% c("normal", "alert", "flash")))
+    stop("updateAceEditor: Incorrectly formatted border parameter")
+  if(!is.empty(autoCompleters) && !all(autoCompleters %in% c("snippet", "text", "keyword", "static", "rlang")))
+    stop("updateAceEditor: Incorrectly formatted autoCompleters parameter")
 
   theList <- list(id = editorId)
 
@@ -72,15 +78,16 @@ updateAceEditor <- function(
   }
 
   if (!missing(autoComplete)) {
-    autoComplete <- match.arg(autoComplete)
+    if (is.empty(autoCompleters)) {
+      autoComplete <- "disabled"
+    } else {
+      autoComplete <- match.arg(autoComplete)
+    }
     theList["autoComplete"] <- autoComplete
   }
 
-  if (!missing(autoCompleters)) {
-    if (!is.null(autoCompleters)) {
-      autoCompleters <- match.arg(autoCompleters, several.ok = TRUE)
-    }
-    theList <- c(theList, list(autoCompleters = autoCompleters))
+  if (!missing(autoCompleters) && !is.empty(autoCompleters)) {
+    theList <- c(theList, list(autoCompleters = match.arg(autoCompleters, several.ok = TRUE)))
   }
 
   if (!missing(autoCompleteList)) {
